#!/bin/sh
#
# Configuration restoration is ONLY for embedded systems.
# Should probably have SWBD test up front, but for now
# this is only installed on suitable platforms.
#
configroot=/etc/fabos
part2root=/mnt

usagestr="$0: -factory -force -nobackup -restore -help -quiet -verify"

# Print list of files and actions taken
doverbose=1
# Type of config save/restore operation, the only one for now.
dofactory=0
# Set this for restore operation, default operation is save
dorestore=0
# Show is even more verbose, and not on help list
doshow=0
# Set this to save on top of existing saved config
doforce=0
# Normally update the second partition as well, both save and restore
dopart2=1
# Yet another kind of verbosity, mostly subsumed by verify option
#dols=1
# Remove first, perhaps permissions are why restoration was failing
dorm=1
# Verify that files are probably identical
doverify=0

# may use command line name to determine function
prog=`basename $0 .sh` 

# pick up command line options
for arg in $prog ${*-NONE}
do case $arg in
      configsave) dosave=1 ; dorestore=0 ;;
      --save|-save) dosave=1 ; dorestore=0 ;;
      --factory|-factory) dofactory=1 ;;
      --force|-force) doforce=1 ;;
      --backup|-backup) dopart2=1 ;;
      --nobackup|-nobackup) dopart2=0 ;;
      --dols|-dols) dols=1 ;;
      --nols|-nols) dols=0 ;;
## not yet      configrestore) dosave=0 ; dorestore=1 ;;
      --restore|-restore) dorestore=1 ; dosave=0 ;;
      --verbose|-verbose) doverbose=1 ;;
      --verify|-verify) doverify=1 ;;
      --quiet|-quiet) doverbose=0 ;;
      --help|-help) echo "$usagestr" ; exit ;;
## debug only      -show) doshow=1 ;;
      NONE)  echo "$usagestr" ; exit ;;
      -*) echo "$0: Unknown option $arg" ; exit 1;;
      *) echo "$0: Unknown command name $arg" ; exit 1;;
   esac
done

# compute full path names later, will allow test mode
saverootdir=${configroot}/cfgsave
factdir=${saverootdir}/factory
licensefile=${configroot}/licenses
part2=${part2root}
syncfile=${configroot}/sync.conf
savefile=${factdir}/savedfiles-list.txt

# classify files in various ways
# The lines of the sync conf file consist of a digit flag, followed
# by a file name, and then optionally followed by a program name
#
# Example:
#    1   /etc/syslog.conf   /fabos/libexec/syslog_cfg
#
# This sed edit command allows for variable white space between field1
# (the flag digit) and field2 (the interesting file name). Everything
# after field2 is ignored

for f in `sed -e "s/^[ 	]*[0-9]\+[ 	]\+\([^ 	]\+\).*/\1/" < ${syncfile}` 
do case $f in
    /etc*) # all existing files will be saved the first time
	   if test -f $f ;
           then foundlist="${foundlist-} $f"
           else missinglist="${missinglist-} $f"
           fi
           # track saved vs current files
           if test -f ${factdir}$f ;
           then savedlist="${savedlist-} $f"
           else notsavedlist="${notsavedlist-} $f"
           fi
	   # if we have saved version and real version, replace unless licenses
           ## if test -f ${factdir}$f -a -f $f ;
           ## then replacelist="${replacelist-} $f"
           ## fi
	   # if we have real version but none saved: delete unless licenses
           if test -f $f -a ! -f ${factdir}$f ;
           then removelist="${removelist-} $f"
           fi
	   ;;
   esac ;
done

if test "${doshow-0}" -eq 1
then
    echo Found: "${foundlist-<empty>}"
    echo Missing: "${missinglist-<empty>}"
    echo Saved: "${savedlist-<empty>}"
    echo NotSaved: "${notsavedlist-<empty>}"
    ## echo Replace: "${replacelist-<empty>}"
    echo Remove: "${removelist-<empty>}"
fi

if test "${dosave-0}" -eq 1 -a "${dofactory-0}" -eq 1
then
    echo "Saving factory default configuration in $factdir";
    if test -d ${factdir} -o -d ${part2}${factdir} 
    then if test ${doforce-0} -eq 0
        then echo "$0: saved factory configuration already exists."
	    exit 1;
	fi
    fi

    # Cleanup previous config, if there was one
    if test -d ${factdir}
    then rm -rf ${factdir}
    fi
    mkdir -p ${factdir}
    touch ${savefile}

    if test "${doverbose-0}" -eq 1
    then
        for f in ${missinglist-}
        do
            echo "  not saving $f"
        done
    fi

    for f in ${foundlist-}
    do
        if test "${doverbose-0}" -eq 1
        then
	    echo "  saving $f"
        fi
	echo $f >>${savefile}
	mkdir -p `dirname ${factdir}$f`
        cp -p -f $f ${factdir}$f
    done

    # write protect saved file list
    chmod a-w ${savefile}

    # now copy the entire thing to the other partition
    if test ${dopart2-1} != 0
    then
        echo "$prog: Copying saved configuration to backup partition"
        if test -d ${part2}${factdir}
        then rm -rf ${part2}${factdir}
        fi
        mkdir -p ${part2}${factdir}
        pushd ${factdir}
        cp -r -p -f . ${part2}${factdir}
	popd
        echo "$prog: Factory configuration files save complete"
    else
        echo "$prog: Warning: Not copying saved files to backup partition"
    fi
fi

if test "${dorestore-0}" -eq 1 -a "${dofactory-0}" -eq 1
then
    echo "$prog: Restoring factory default configuration from ${factdir}";
    if test ! -d ${factdir} -o ! -f ${savefile} -o ! -s ${savefile}
    then echo "$0: error, no saved factory configuration."
	exit 1;
    fi

    ### Do not remove files for time being to workaround 4.3 upgrade issue
    ### Not a permanent fix.
    removelist=
    for f in ${removelist-}
    do
        if test $f = $licensefile
        then echo "Licenses left unchanged."
        else
            if test "${doverbose-0}" -eq 1
            then
                 echo "  removing $f"
            fi
            rm $f
            if test ${dopart2-1} != 0
	    then
                if test "${doverbose-0}" -eq 1
                then
                    echo "  removing ${part2}$f"
                fi
                rm ${part2}$f
	    fi
        fi
    done

###    for f in ${savedlist-}
    for f in `cat ${savefile}`
    do
        if test $f = $licensefile
        then echo "Licenses left unchanged."
        else
            if test "${doverbose-0}" -eq 1
            then
                echo "  restoring $f"
            fi
            # option to list file before and after restoration
            if test ${dols-0} != 0 ; then ls -ls $f ; fi
	    if test ${dorm-0} != 0 ; then rm $f ; fi
            cp -p -f ${factdir}$f $f
            if test ${dols-0} != 0 ; then ls -ls $f ; fi
            if test ${dopart2-1} != 0
	    then
                if test "${doverbose-0}" -eq 1
                then
                    echo "  restoring ${part2}$f"
                fi
                if test ${dols-0} != 0 ; then ls -ls ${part2}$f ; fi
                if test ${dorm-0} != 0 ; then rm ${part2}$f ; fi
                cp -p -f ${factdir}$f ${part2}$f
                if test ${dols-0} != 0 ; then ls -ls ${part2}$f ; fi
	    fi
        fi
    done
    echo "$prog: Factory configuration files restoration complete"
fi

# verify option uses ls -ls on each file and compares output
if test "${doverify-0}" = 1
then allmatch=1
    for f in `cat ${savefile}`
    do  if test ! -f "$f" ;
        then continue
        fi 
        d=`dirname $f`
        e=`basename $f`
        curout=`( cd $d ; ls -ls $e )`
        saveout=`( cd /etc/fabos/cfgsave/factory${d} ; ls -ls $e)`
        if test "${curout}" != "${saveout}"
        then echo $f does not match saved configuration
            echo "Current: $curout"
            echo "Saved:   $saveout"
            allmatch=0;
        else if test ${dols-0} != 0
            then echo "Current: $curout"
                echo "Saved:   $saveout"
            fi
        fi
	if test ${dopart2-1} != 0
        then curout=`( cd ${part2}$d ; ls -ls $e )`
            saveout=`( cd ${part2}/etc/fabos/cfgsave/factory${d} ; ls -ls $e)`
            if test "${curout}" != "${saveout}"
            then echo $f does not match saved configuration
                echo "Current(/mnt): $curout"
                echo "Saved(/mnt):   $saveout"
                allmatch=0;
            else if test ${dols-0} != 0
                then echo "Current(/mnt): $curout"
                    echo "Saved(/mnt):   $saveout"
                fi
            fi
	fi
    done
    if test $allmatch = 1
    then echo Verification succeeded.
    else echo Verification failed.
    fi
fi
